@@ -1,4 +1,3 @@
-from typing import Optional
 from .print_stuff import PrintColor
 
 
@@ -22,15 +21,14 @@ class Plugin(object):
         """
         raise NotImplementedError
 
-    def stats(self, directive: str, data: dict) -> {str: int}:
+    def stats(self, directive: str, data: dict) -> ({str: int}, {str: str}):
         """
         Return the stats for the directive
         """
         raise NotImplementedError
 
-    @staticmethod
-    def get_directives() -> [str]:
+    def info(self, directive: str, data: dict):
         """
-        Return all the directive
+        Return info of the directive
         """
-        raise NotImplementedError
\ No newline at end of file
+        return data.get(directive, dict())
